==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/PreferredSchedulingTermBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PreferredSchedulingTermBuilder extends io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluentImpl<io.fabric8.kubernetes.api.model.PreferredSchedulingTermBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PreferredSchedulingTerm,io.fabric8.kubernetes.api.model.PreferredSchedulingTermBuilder>{
  public PreferredSchedulingTermBuilder() {
    this(false);
  }
  public PreferredSchedulingTermBuilder(java.lang.Boolean validationEnabled) {
    this(new PreferredSchedulingTerm(), validationEnabled);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent) {
    this(fluent, false);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PreferredSchedulingTerm(), validationEnabled);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent,io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance) {
    this(fluent, instance, false);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent,io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPreference(instance.getPreference()); 
    fluent.withWeight(instance.getWeight()); 
    this.validationEnabled = validationEnabled; 
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance) {
    this(instance,false);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPreference(instance.getPreference()); 
    this.withWeight(instance.getWeight()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTerm build() {
    PreferredSchedulingTerm buildable = new PreferredSchedulingTerm(fluent.getPreference(),fluent.getWeight());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PreferredSchedulingTermBuilder that = (PreferredSchedulingTermBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PreferredSchedulingTermBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PreferredSchedulingTermBuilder extends io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluentImpl<io.fabric8.kubernetes.api.model.PreferredSchedulingTermBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PreferredSchedulingTerm,io.fabric8.kubernetes.api.model.PreferredSchedulingTermBuilder>{
  public PreferredSchedulingTermBuilder() {
    this(false);
  }
  public PreferredSchedulingTermBuilder(java.lang.Boolean validationEnabled) {
    this(new PreferredSchedulingTerm(), validationEnabled);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent) {
    this(fluent, false);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PreferredSchedulingTerm(), validationEnabled);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent,io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance) {
    this(fluent, instance, false);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent,io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPreference(instance.getPreference()); 
    fluent.withWeight(instance.getWeight()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance) {
    this(instance,false);
  }
  public PreferredSchedulingTermBuilder(io.fabric8.kubernetes.api.model.PreferredSchedulingTerm instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPreference(instance.getPreference()); 
    this.withWeight(instance.getWeight()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PreferredSchedulingTermFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PreferredSchedulingTerm build() {
    PreferredSchedulingTerm buildable = new PreferredSchedulingTerm(fluent.getPreference(),fluent.getWeight());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PreferredSchedulingTermBuilder that = (PreferredSchedulingTermBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
